==> edpsgui-0.8.0.tar.gz: edpsgui-0.8.0/src/edpsgui/gui/tooltips.py <==
START_EDPS = """
**Start EDPS**
Start the EDPS (ESO Data Processing System) server. The EDPS server
should always be running for this GUI to work.
"""

STOP_EDPS = """
**Stop EDPS**
The EDPS server should only be stopped in case of a problem that is
likely to be caused by the server. The EDPS must then be re-started
before the GUI can be used again.
"""

START_STOP_EDPS = f"""
{START_EDPS}
{STOP_EDPS}
"""

SELECT_WORKFLOW = """
**Workflow**
Select the workflow for the data to be processed.
Only data that correspond to the selected workflow will be processed.
"""

TOPBAR_TOOLTIP = f"""
{START_STOP_EDPS}
{SELECT_WORKFLOW}
"""

SELECT_INPUT_DATA = """
**Select inputs**
Select the input files to be processed.
The selected data must correspond to the selected workflow.
"""

INSPECT_INPUT_DATA = """
**Inspect inputs**
Inspect the selected input files. All data that are recognized by the selected 
workflows will categorized and listed. 
"""

SELECT_TARGET = """
**Select target**
Select the task(s) that produce the output you want to obtain. By default, all 
tasks that produce output useful for science are pre-selected.
"""

CONFIGURE_ASSOCIATION = """
**Configure association**
Configure how calibration data are selected. The default configuration selects
unprocessed raw calibrations for re-processing if possible, and uses 
calibration data of any quality. 
"""

CREATE_DATASETS = """
**Create datasets**
Identify the science data among the selected input files, and
list them together with the necessary calibration files to process
them. Datasets that include all necessary files for processing 
will be marked as "complete". 
"""

SAVE_COMMENT = """
**Save**
Update the comment for the current dataset configuration.
"""

COPY_COMMENT = """
**Copy**
Apply this comment to the selected configurations. You can choose to _append_ it to the existing comment or _replace_ the current one entirely.
"""

COMMENT_TOOLTIP = f"""
{SAVE_COMMENT}
{COPY_COMMENT}
"""

SAVE_CONFIGURATION = """
**Save**
Save the current configuration. Only unprocessed (NEW) configurations can be modified.
"""

SAVE_AS_NEW_CONFIGURATION = """
**Save as new**
Create a new configuration based on the current one.
Once saved, you can edit it without affecting the original.
"""

COPY_CONFIGURATION = """
**Copy**
Apply the current configuration’s parameters to the selected configurations.
If a configuration has already been processed, it cannot be changed. Instead, a new version will be created.
"""

CONFIGURATION_TOOLTIP = f"""
{SAVE_CONFIGURATION}
{SAVE_AS_NEW_CONFIGURATION}
{COPY_CONFIGURATION}
"""

REDUCE_DATA = """
**Processing queue**
This section shows all datasets ready to be processed. A reduction can be 
configured and/or submitted for processing. If a previously completed reduction 
exists, it can be used to configure a new reduction.
"""

MONITOR_REDUCTION = """
**Processing monitor**
This section shows the state of submitted processing requests.
"""

EXPORT_DATA = """
**Archived data**
This section lists all datasets that have been completely processed and 
marked as to be archived in the "Processing Queue" tab. From here, the results 
can be exported using human-readable file names. 
"""

==> edpsgui-0.9.0.tar.gz: edpsgui-0.9.0/src/edpsgui/gui/tooltips.py <==
START_EDPS = """
**Start EDPS**
Start the EDPS (ESO Data Processing System) server. The EDPS server
should always be running for this GUI to work.
"""

STOP_EDPS = """
**Stop EDPS**
The EDPS server should only be stopped in case of a problem that is
likely to be caused by the server. The EDPS must then be re-started
before the GUI can be used again.
"""

START_STOP_EDPS = f"""
{START_EDPS}
{STOP_EDPS}
"""

SELECT_WORKFLOW = """
**Workflow**
Select the workflow for the data to be processed.
Only data that correspond to the selected workflow will be processed.
"""

TOPBAR_TOOLTIP = f"""
{START_STOP_EDPS}
{SELECT_WORKFLOW}
"""

SELECT_INPUT_DATA = """
**Select inputs**
Select the input files to be processed.
The selected data must correspond to the selected workflow.
"""

INSPECT_INPUT_DATA = """
**Inspect inputs**
Inspect the selected input files. All data that are recognized by the selected 
workflows will categorized and listed. 
"""

SELECT_TARGET = """
**Select target**
Select the task(s) that produce the output you want to obtain. By default, all 
tasks that produce output useful for science are pre-selected.
"""

CONFIGURE_ASSOCIATION = """
**Configure association**
Configure how calibration data are selected. The default configuration selects
unprocessed raw calibrations for re-processing if possible, and uses 
calibration data of any quality. 
"""

PARAMETER_SET = """
**Parameter sets** are predefined collections of recipe and workflow parameters tailored for specific use cases,
such as quality control or science data reduction. By default the "science" parameter set is selected.
"""

WORKFLOW_PARAMETERS = """
**Workflow parameters** define the overall data reduction strategy, including:
- enabling or disabling specific tasks,
- including or excluding certain types of calibrations,
- setting common recipe parameters for multiple tasks.
"""

CALIBRATION_PREFERENCE = """
This setting determines which calibration data to use when both raw and master calibrations are available. The options are:
- RAW: Always use reduced raw data results, even if master calibrations closer in time exist.
- MASTER: Always use master calibrations, even if reduced raw data results closer in time exist.
- RAW_PER_QUALITY_LEVEL: Use the calibration closest in time, but prefer reduced raw data results when quality levels are equal.
- MASTER_PER_QUALITY_LEVEL: Use the calibration closest in time, but prefer master calibrations when quality levels are equal.
"""

CREATE_DATASETS = """
**Create datasets**
Identify the science data among the selected input files, and
list them together with the necessary calibration files to process
them. Datasets that include all necessary files for processing 
will be marked as "complete". 
"""

SAVE_COMMENT = """
**Save**
Update the comment for the current dataset configuration.
"""

COPY_COMMENT = """
**Copy**
Apply this comment to the selected configurations. You can choose to _append_ it to the existing comment or _replace_ the current one entirely.
"""

COMMENT_TOOLTIP = f"""
{SAVE_COMMENT}
{COPY_COMMENT}
"""

SAVE_CONFIGURATION = """
**Save**
Save the current configuration. Only unprocessed (NEW) configurations can be modified.
"""

SAVE_AS_NEW_CONFIGURATION = """
**Save as new**
Create a new configuration based on the current one.
Once saved, you can edit it without affecting the original.
"""

COPY_CONFIGURATION = """
**Copy**
Apply the current configuration’s parameters to the selected configurations.
If a configuration has already been processed, it cannot be changed. Instead, a new version will be created.
"""

CONFIGURATION_TOOLTIP = f"""
{SAVE_CONFIGURATION}
{SAVE_AS_NEW_CONFIGURATION}
{COPY_CONFIGURATION}
"""

REDUCE_DATA = """
**Processing queue**
This section shows all datasets ready to be processed. A reduction can be 
configured and/or submitted for processing. If a previously completed reduction 
exists, it can be used to configure a new reduction.
"""

MONITOR_REDUCTION = """
**Processing monitor**
This section shows the state of submitted processing requests.
"""

EXPORT_DATA = """
**Archived data**
This section lists all datasets that have been completely processed and 
marked as to be archived in the "Processing Queue" tab. From here, the results 
can be exported using human-readable file names. 
"""
